BOOKIE = {
    'BET365': {
        'B365H': 'HOME_ODDS',
        'B365D': 'DRAW_ODDS',
        'B365A': 'AWAY_ODDS'
    },
    'PS': {
        'PSH': 'HOME_ODDS',
        'PSD': 'DRAW_ODDS',
        'PSA': 'AWAY_ODDS'
    },
    'WH': {
        'WHH': 'HOME_ODDS',
        'WHD': 'DRAW_ODDS',
        'WHA': 'AWAY_ODDS'
    },
    'BWIN': {
        'BWH': 'HOME_ODDS',
        'BWD': 'DRAW_ODDS',
        'BWA': 'AWAY_ODDS'
    },
    'LB': {
        'LBH': 'HOME_ODDS',
        'LBD': 'DRAW_ODDS',
        'LBA': 'AWAY_ODDS'
    }
}


MATCH_INFO = [
    'DATE', 'SEASON', 'COUNTRY', 'LEAGUE', 'DIV',
    'HOMETEAM', 'AWAYTEAM', 'FTAG', 'FTHG', 'FTR'
]